import { Box, Typography } from '@material-ui/core'
import { Alert, AlertTitle } from '@material-ui/lab'
import React, { useContext, useEffect, useState } from 'react'
import { AuthContext } from '../../../store/auth'
import { FetchContext } from '../../../store/fetch'
import { Spinner } from '../../icons'
import styles from './TelegramConnect.module.css'

const TelegramConnect = () => {
  const [code, setCode] = useState('')
  const [isLoading, setIsLoading] = useState(true)
  const [error, setError] = useState('')
  const [isConnected, setIsConnected] = useState(false)
  const { authAxios } = useContext(FetchContext)
  const { authState } = useContext(AuthContext)
  const isTelegramConnected = authState.userInfo?.isTelegramConnected
  const username = authState.userInfo?.username

  const getTelegramCode = async () => {
    try {
      const { data, status } = await authAxios.post('/user/createtgcode', {
        username
      })
      if (status === 200) {
        if (data.user.isTelegramConnected) {
          setIsConnected(true)
          setIsLoading(false)
          setError('Already connected')
        } else {
          setCode(data.user.telegramConnectionCode)
          setIsLoading(false)
        }
      }
    } catch (e) {
      if (e.response.status === 400) {
        setIsConnected(true)
        setIsLoading(false)
        setError('Already connected')
      } else {
        setError('Something went wrong while creating the code')
        setIsLoading(false)
      }
    }
  }

  useEffect(() => {
    if (!isTelegramConnected) {
      getTelegramCode()
    } else {
      setIsLoading(false)
      setIsConnected(true)
    }
  }, [])
  return (
    <Box sx={{ mt: '10px' }}>
      <Typography variant="h5" align="center">
        Just one step away from connecting your Telegram account
      </Typography>
      {isLoading ? (
        <div className="loading">
          <Spinner />
        </div>
      ) : isConnected ? (
        <div className={styles.tg_connect_container}>
          <Alert variant="filled" severity="success">
            <AlertTitle>Conencted</AlertTitle>
            You are already connected to Telegram
          </Alert>
        </div>
      ) : (
        <div className={styles.tg_connect_container}>
          <Typography variant="h3" align="center">
            Your code is
          </Typography>
          <div className={styles.code_number_container}>
            {code &&
              Array.from(String(code), Number).map((char, index) => {
                return (
                  <span className={styles.code_number} key={index}>
                    {char}
                  </span>
                )
              })}
          </div>
          <Typography variant="h6" align="center">
            Once you've sent the code, click the Verify button.
          </Typography>
        </div>
      )}
    </Box>
  )
}

export default TelegramConnect
